==> jc-1.4.0.tar.gz: javax/swing/plaf/SliderUI.h <==
// public abstract class javax.swing.plaf.SliderUI

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 9f393451fe8ae81c javax_swing_plaf_ComponentUI
// @dep_class d511e11d9ce2498 javax_swing_plaf_SliderUI

// header file dependencies
// @dep_header javax_swing_plaf_ComponentUI

#include "javax/swing/plaf/ComponentUI.h"

#ifndef _JC_javax_swing_plaf_SliderUI_H_
#define _JC_javax_swing_plaf_SliderUI_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_SliderUI$sub_refs	_jc_javax_swing_plaf_SliderUI$sub_refs;
typedef struct _jc_javax_swing_plaf_SliderUI$sub_nonrefs	_jc_javax_swing_plaf_SliderUI$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_SliderUI$refs	_jc_javax_swing_plaf_SliderUI$refs;
typedef struct _jc_javax_swing_plaf_SliderUI$nonrefs	_jc_javax_swing_plaf_SliderUI$nonrefs;
typedef struct _jc_javax_swing_plaf_SliderUI$object	_jc_javax_swing_plaf_SliderUI$object;

typedef const struct _jc_javax_swing_plaf_SliderUI$vmethods	_jc_javax_swing_plaf_SliderUI$vmethods;
typedef const struct _jc_javax_swing_plaf_SliderUI$vtable	_jc_javax_swing_plaf_SliderUI$vtable;
typedef const struct _jc_javax_swing_plaf_SliderUI$vtype	_jc_javax_swing_plaf_SliderUI$vtype;

// Constructors
extern void _jc_javax_swing_plaf_SliderUI$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_plaf_SliderUI$object *);

// Virtual methods structure
struct _jc_javax_swing_plaf_SliderUI$vmethods {
};

// Vtable
struct _jc_javax_swing_plaf_SliderUI$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_plaf_ComponentUI$vmethods	javax_swing_plaf_ComponentUI;
	_jc_javax_swing_plaf_SliderUI$vmethods	javax_swing_plaf_SliderUI;
};

// Vtype
struct _jc_javax_swing_plaf_SliderUI$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_SliderUI$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_SliderUI$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_SliderUI$refs {
    _jc_javax_swing_plaf_SliderUI$sub_refs	javax_swing_plaf_SliderUI;
    _jc_javax_swing_plaf_ComponentUI$sub_refs	javax_swing_plaf_ComponentUI;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_SliderUI$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_SliderUI$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_plaf_ComponentUI$sub_nonrefs	javax_swing_plaf_ComponentUI;
    _jc_javax_swing_plaf_SliderUI$sub_nonrefs	javax_swing_plaf_SliderUI;
};

// Object instance structure
struct _jc_javax_swing_plaf_SliderUI$object {
	_jc_javax_swing_plaf_SliderUI$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_SliderUI$vtype	*vtype;
	_jc_javax_swing_plaf_SliderUI$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_SliderUI$vtype _jc_javax_swing_plaf_SliderUI$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_SliderUI, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_SliderUI$class_object;

#endif	/* _JC_javax_swing_plaf_SliderUI_H_ */

==> jc-1.4.6.tar.gz: javax/swing/plaf/SliderUI.h <==
// public abstract class javax.swing.plaf.SliderUI

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 9f393451fe8ae81c javax_swing_plaf_ComponentUI
// @dep_class d511e11d9ce2498 javax_swing_plaf_SliderUI

// header file dependencies
// @dep_header javax_swing_plaf_ComponentUI

#include "javax/swing/plaf/ComponentUI.h"

#ifndef _JC_javax_swing_plaf_SliderUI_H_
#define _JC_javax_swing_plaf_SliderUI_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_SliderUI$sub_refs	_jc_javax_swing_plaf_SliderUI$sub_refs;
typedef struct _jc_javax_swing_plaf_SliderUI$sub_nonrefs	_jc_javax_swing_plaf_SliderUI$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_SliderUI$refs	_jc_javax_swing_plaf_SliderUI$refs;
typedef struct _jc_javax_swing_plaf_SliderUI$nonrefs	_jc_javax_swing_plaf_SliderUI$nonrefs;
typedef struct _jc_javax_swing_plaf_SliderUI$object	_jc_javax_swing_plaf_SliderUI$object;

typedef const struct _jc_javax_swing_plaf_SliderUI$vmethods	_jc_javax_swing_plaf_SliderUI$vmethods;
typedef const struct _jc_javax_swing_plaf_SliderUI$vtable	_jc_javax_swing_plaf_SliderUI$vtable;
typedef const struct _jc_javax_swing_plaf_SliderUI$vtype	_jc_javax_swing_plaf_SliderUI$vtype;

// Constructors
extern void _jc_javax_swing_plaf_SliderUI$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_plaf_SliderUI$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_swing_plaf_SliderUI$vmethods {
};

// Vtable
struct _jc_javax_swing_plaf_SliderUI$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_plaf_ComponentUI$vmethods	javax_swing_plaf_ComponentUI;
	_jc_javax_swing_plaf_SliderUI$vmethods	javax_swing_plaf_SliderUI;
};

// Vtype
struct _jc_javax_swing_plaf_SliderUI$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_SliderUI$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_SliderUI$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_SliderUI$refs {
    _jc_javax_swing_plaf_SliderUI$sub_refs	javax_swing_plaf_SliderUI;
    _jc_javax_swing_plaf_ComponentUI$sub_refs	javax_swing_plaf_ComponentUI;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_SliderUI$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_SliderUI$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_plaf_ComponentUI$sub_nonrefs	javax_swing_plaf_ComponentUI;
    _jc_javax_swing_plaf_SliderUI$sub_nonrefs	javax_swing_plaf_SliderUI;
};

// Object instance structure
struct _jc_javax_swing_plaf_SliderUI$object {
	_jc_javax_swing_plaf_SliderUI$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_SliderUI$vtype	*vtype;
	_jc_javax_swing_plaf_SliderUI$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_SliderUI$vtype _jc_javax_swing_plaf_SliderUI$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_SliderUI, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_SliderUI$class_object;

#endif	/* _JC_javax_swing_plaf_SliderUI_H_ */
